.. image:: https://badge.waffle.io/BD2KGenomics/toil.svg?label=ready&title=Ready
   :target: https://waffle.io/BD2KGenomics/toil
   :alt: 'Stories in Ready'

Toil is a scalable, efficient, cross-platform pipeline management system,
written entirely in Python, and designed around the principles of functional
programming. Full documentation for the latest stable release can be found at
`Read the Docs`_.

.. _Read the Docs: http://toil.readthedocs.org/
